# This file is needed for editable installs (`pip install -e .`).
# Can be removed once the following is resolved
# https://github.com/pypa/packaging-problems/issues/256
from setuptools import setup

setup()
